@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 """Date parsing utilities"""
+import time
 from calendar import monthrange
 from datetime import datetime
 from parser import ParserError
@@ -7,6 +8,7 @@ from typing import Optional, Dict, Tuple
 
 import dateutil
 from dateutil.parser import _timelex, parserinfo
+from dateutil.tz import tzutc
 
 from hdx.utilities import raisefrom
 
@@ -613,17 +615,34 @@ def parse_date(string, date_format=None, fuzzy=None, zero_time=False):
     return startdate
 
 
-def get_date_from_timestamp(timestamp, today=datetime.now()):
-    # type: (float, datetime) -> datetime
+def get_timestamp_from_datetime(date):
+    # type: (datetime) -> float
+    """Convert datetime to timestamp.
+
+    Args:
+        date (datetime): Date to convert
+
+    Returns:
+        float: Timestamp
+    """
+    if date.tzinfo is None:
+        return time.mktime((date.year, date.month, date.day, date.hour, date.minute, date.second, -1, -1, -1)) + date.microsecond / 1e6
+    else:
+        return (date - datetime(1970, 1, 1, tzinfo=tzutc())).total_seconds()
+
+
+def get_datetime_from_timestamp(timestamp, timezone=tzutc, today=datetime.now(tzutc())):
+    # type: (float, datetime.tzinfo, datetime) -> datetime
     """Convert timestamp to datetime.
 
     Args:
         timestamp (float): Timestamp to convert
+        timezone (datetime.tzinfo): Timezone to use
         today (datetime): Today's date. Defaults to datetime.now().
 
     Returns:
         datetime: Date of timestamp
     """
-    if timestamp > today.timestamp():
+    if timestamp > get_timestamp_from_datetime(today):
         timestamp = timestamp / 1000
-    return datetime.fromtimestamp(timestamp)
+    return datetime.fromtimestamp(timestamp, tz=timezone)
